using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Linq.Expressions;
using System.Web;

namespace NorthwindWeb.Models
{ 
    public class SupplierRepository : ISupplierRepository
    {
        NorthwindEntities context = new NorthwindEntities();

        public IQueryable<Supplier> All
        {
            get { return context.Suppliers; }
        }

        public IQueryable<Supplier> AllIncluding(params Expression<Func<Supplier, object>>[] includeProperties)
        {
            IQueryable<Supplier> query = context.Suppliers;
            foreach (var includeProperty in includeProperties) {
                query = query.Include(includeProperty);
            }
            return query;
        }

        public Supplier Find(int id)
        {
            return context.Suppliers.Single(x => x.SupplierID == id);
        }

        public void InsertOrUpdate(Supplier supplier)
        {
            if (supplier.SupplierID == default(int)) {
                // New entity
                context.Suppliers.AddObject(supplier);
            } else {
                // Existing entity
                context.Suppliers.Attach(supplier);
                context.ObjectStateManager.ChangeObjectState(supplier, EntityState.Modified);
            }
        }

        public void Delete(int id)
        {
            var supplier = context.Suppliers.Single(x => x.SupplierID == id);
            context.Suppliers.DeleteObject(supplier);
        }

        public void Save()
        {
            context.SaveChanges();
        }
    }

    public interface ISupplierRepository
    {
        IQueryable<Supplier> All { get; }
        IQueryable<Supplier> AllIncluding(params Expression<Func<Supplier, object>>[] includeProperties);
        Supplier Find(int id);
        void InsertOrUpdate(Supplier supplier);
        void Delete(int id);
        void Save();
    }
}